==> vmp-0.7.1.tar.xz: vmp-0.7.1/framework/src/jrp/misc/status.h <==
/* -*- Mode:C++; c++-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella alias Vasta 
 * Web page:<www.ragnu.it> 
 * Email:<vasta@ragnu.it>
   Date last update: 25/09/2024
*/

#ifndef VAMPIRIA_JRP_MISC_STATUS_H

#define VAMPIRIA_JRP_MISC_STATUS_H 1

namespace vampiria { namespace jrp { namespace misc {

//!Returns the default input for the status request
vmp::str status_input();

//!Returns the default push for the status request
vmp::vector<vmp::str> status_push();

//!Returns the default outputs for the status request
vmp::vector<vmp::str> status_response();

//!  A class used to manage the state of the dynamic system managed by a process.
//!  These are a json data table representing state variables
class Status
{
    private:
        vmp::thread::Mutex mutex_;/*!<Internal usage mutual exclusion */
        json::Json root_;/*!<State memory*/
        json::JTable jtable_;/*!<Internal usage*/
        vmp::Table<vmp::str,jrp::JrpReq *> jreqs_;/*!< Json request table to send status update to*/
        vmp::str dirpath_;/*!<Directory used to store status files*/
        vmp::str filecache_;/*!<Internal usage*/
        vmp::str id_;/*!<Status id*/

        //!Internal usage
        void cache();

        //!Internal usage
        void broadcast(json::JsonObj *jdata);
    public:
        //! A Constructor
        /*!
            @param dirpath Directory used to store status files
            @param cached if set to true on startup restores state saved in cache file, otherwise initializes an empty state
            @param id status id
            @return except in case of failure
        */
        Status(vmp::str dirpath,vmp_bool cached=true,vmp::str id="");
        
        //!A Destructor
        ~Status();
        
        //! Return the root json parser
        /*!
            @ref root_
            @return pointer json parser
            
        */
        json::Json *root();
        
        //! Writes the State to a backup file
        void backup();
        
        //! Return table keys that have the jtype variable
        /*!
            @param jtype datatype, if == "" all the keys are returned
            @return outputs keys or except in case of failure
        */
        vmp::vector<vmp::str> keys(vmp::str jtype="");

        //!Update or insert the value of a status variable
        /*!
            @param jkey key of the variable
            @param jdata json data variable
            @return void or except in case of failure
        */
        void update(vmp::str jkey,json::JsonObj *jdata);

        //!Update or insert the value of a status variable
        /*!
            @param jstatus a json data of type json::japi("statusupdate")
            @return void or except in case of failure
        */
        void update_from_japi(json::JsonObj *jstatus);

        //! Delete a variable from the state
        /*!
            @param jkey key of the variable
        */
        void cancel(vmp::str jkey);

        //! Delete a variable from the state
        /*!
            @param jstatus a json data of type json::japi("statuscancel")
            @return void or except in case of failure
        */
        void cancel_from_japi(json::JsonObj *jstatus);

        //! Search for a status variable
        /*!
            @param jkey key of the variable
            @param jdata output data
            @return True if the variable exists, otherwise false or except in case of failure

        */
        vmp_bool search(vmp::str jkey,json::JsonObj *jdata);

        //! Open an external monitoring request
        /*!
            @param jreq jrp request associated
            @return void or except in case of failure
        */
        void request_open(jrp::JrpReq *jreq);
        
        //! Close an external monitoring request(send jrp close to associated peer)
        /*!
            @param jreqkey Key associated with the request to be closed
            @param status closing state 
            @param msg closing state in string format
            @return void or except in case of failure
        */
        void request_close(vmp::str jreqkey,vmp_int status,vmp::str msg="");
};

}}}

#endif

==> vmp-0.7.3.tar.xz: vmp-0.7.3/framework/src/jrp/misc/status.h <==
/* -*- Mode:C++; c++-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella alias Vasta 
 * Web page:<www.ragnu.it> 
 * Email:<vasta@ragnu.it>
   Date last update: 27/12/2024
*/

#ifndef VAMPIRIA_JRP_MISC_STATUS_H

#define VAMPIRIA_JRP_MISC_STATUS_H 1

namespace vampiria { namespace jrp { namespace misc {

//!  A class used to manage the state of the dynamic system managed by a process.
//!  These are a json data table representing state variables
class Status:public jrp::misc::JrpApi_I
{
    private:
        vmp::thread::Mutex mutex_;/*!<Internal usage mutual exclusion */
        json::Json root_;/*!<State memory*/
        json::JTable jtable_;/*!<Internal usage*/
        vmp::Table<vmp::str,jrp::JrpReq *> jreqs_;/*!<Json request table to send status update to*/
        vmp::Table<vmp::str,vmp::vector<vmp_index> >limits_;/*!<Restrict the permissions for keys to send to users*/
        vmp::str dirpath_;/*!<Directory used to store status files*/
        vmp::str filecache_;/*!<Internal usage*/
        
        //!Internal usage
        void cache();
        
        //!Internal usage
        vmp_bool islimit(vmp::str jtype,jrp::JrpReq *jreq);
        
        //!Internal usage
        void broadcast(json::JsonObj *jdata,vmp::str jkey);
    public:
        //! A Constructor
        /*!
            @param dirpath Directory used to store status files
            @param cached if set to true on startup restores state saved in cache file, otherwise initializes an empty state
            @return except in case of failure
        */
        Status(vmp::str dirpath,vmp_bool cached=true);
        
        //!A Destructor
        ~Status();
        
        //! Return the root json parser
        /*!
            @ref root_
            @return pointer json parser
            
        */
        json::Json *root();
        
        //!Restrict the permissions for keys to send to users
        /*!
            @ref limits_
            @param jkey jdata key
            @param permits accepted permission range
        */
        void set_limit(vmp::str jkey,vmp::str permits);
        
        //! Writes the State to a backup file
        void backup();
        
        //! Return table keys that have the jtype variable
        /*!
            @param jtype datatype, if == "" all the keys are returned
            @return outputs keys or except in case of failure
        */
        vmp::vector<vmp::str> keys(vmp::str jtype="");

        //!Update or insert the value of a status variable
        /*!
            @param jkey key of the variable
            @param jdata json data variable
            @return void or except in case of failure
        */
        void update(vmp::str jkey,json::JsonObj *jdata);

        //!Update or insert the value of a status variable
        /*!
            @param jstatus a json data of type json::japi("statusupdate")
            @return void or except in case of failure
        */
        void update_from_japi(json::JsonObj *jstatus);

        //! Delete a variable from the state
        /*!
            @param jkey key of the variable
        */
        void cancel(vmp::str jkey);

        //! Delete a variable from the state
        /*!
            @param jstatus a json data of type json::japi("statuscancel")
            @return void or except in case of failure
        */
        void cancel_from_japi(json::JsonObj *jstatus);

        //! Search for a status variable
        /*!
            @param jkey key of the variable
            @param jdata output data
            @return True if the variable exists, otherwise false or except in case of failure

        */
        vmp_bool search(vmp::str jkey,json::JsonObj *jdata);

        //! Open an external monitoring request
        /*!
            @param jreq jrp request associated
            @return void or except in case of failure
        */
        void request_open(jrp::JrpReq *jreq);
        
        //! Close an external monitoring request(send jrp close to associated peer)
        /*!
            @param jreqkey Key associated with the request to be closed
            @param status closing state 
            @param msg closing state in string format
            @return void or except in case of failure
        */
        void request_close(vmp::str jreqkey,vmp_int status,vmp::str msg="");
        
        //! virtual function
        void register_common(jrp::JrpCommon *common,vmp::str permits="*");
        
        //! virtual function
        void management_impl(jrp::JrpReq *jreq,vmp::Buf *payload);
        
        //! virtual function
        void management_kill_impl(jrp::JrpReq *jreq);
};

}}}

#endif
